@@ -218,7 +218,19 @@ int main(int argc, char *argv[])
   #endif
 #endif
     
-
+#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
+    // Unset platform theme plugins/styles environment variables immediately
+    // when forcing Sigil's own darkmode palette on Linux
+    if (!force_sigil_darkmode_palette.isEmpty() ||
+	!force_pageedit_darkmode_palette.isEmpty()) {
+        QStringList env_vars = {"QT_QPA_PLATFORMTHEME", "QT_STYLE_OVERRIDE"};
+        foreach(QString v, env_vars) {
+            bool irrel = qunsetenv(v.toUtf8().constData());
+        Q_UNUSED(irrel);
+        }
+    }
+#endif
+    
 #ifndef QT_DEBUG
     qInstallMessageHandler(MessageHandler);
 #endif
@@ -244,6 +256,20 @@ int main(int argc, char *argv[])
 #endif
     QCoreApplication::setAttribute(Qt::AA_DisableShaderDiskCache);
 
+    // enable disabling of gpu acceleration for QtWebEngine.
+    // append to current environment variable contents as numerous chromium 
+    // switches exist that may be useful
+    SettingsStore nss;
+    if (nss.disableGPU()) {
+        QString current_flags = Utility::GetEnvironmentVar("QTWEBENGINE_CHROMIUM_FLAGS");
+        if (current_flags.isEmpty()) {
+            current_flags = "--disable-gpu";
+        } else if (!current_flags.contains("--disable-gpu")) {
+            current_flags += " --disable-gpu";
+        }
+        qputenv("QTWEBENGINE_CHROMIUM_FLAGS", current_flags.toUtf8());
+    }
+
     MainApplication app(argc, argv);
 
 #ifdef Q_OS_MAC
@@ -296,7 +322,11 @@ int main(int argc, char *argv[])
     if (!force_pageedit_darkmode_palette.isEmpty() || !force_sigil_darkmode_palette.isEmpty()) {
         // Apply custom dark style
         app.setStyle(new PEDarkStyle);
+#if QT_VERSION == QT_VERSION_CHECK(5, 15, 0)
+        // Qt keeps breaking my custom dark theme.
+        // This was apparently only necessary for Qt5.15.0!!
         app.setPalette(QApplication::style()->standardPalette());
+#endif
     }
 #else
     if (Utility::WindowsShouldUseDarkMode()) {
